from importlib import import_module

from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


__version__ = '0.3'

class EasyConfig(object):
    def __init__(self, default_module, setting_name):
        self.default_module = default_module
        self.setting_name = setting_name

    def _get_config(self):
        ''' Get the config as defined in the settings
        '''
        config = self._get_config_name()
        try:
            package = import_module(config)
        except ImportError:
            path = '.'.join(config.split('.')[:-1])
            pkg = config.split('.')[-1]
            try:
                tmp_package = import_module(path, package=pkg)
                package = getattr(tmp_package, pkg)
            except (ImportError, AttributeError):
                raise ImproperlyConfigured(
                    'The %s setting refers to a non-existing package.' % \
                                                            self.setting_name
                )

        if callable(package):
            package = package()
        return package

    def _get_config_name(self):
        ''' Returns the name of the support config (either the setting value,
            if it exists, or the default).
        '''
        return getattr(settings, self.setting_name, self.default_module)


    def get_object(self, method, default_obj, *args, **kwargs):
        ''' Check that the support config is custom, and if so, that the
            right methods exist. If not, return the default_obj
        '''
        if self._get_config_name() != self.default_module:
            config = self._get_config()
            if hasattr(config, method):
                return getattr(config, method)(*args, **kwargs)

        return default_obj



import os
from distutils.core import setup


version = '0.3'
project_name = 'easyconfig'
long_description = open('README.rst').read()

# Idea from django-registration setup.py
packages, data_files = [], []
root_dir = os.path.dirname(__file__)
if root_dir:
    os.chdir(root_dir)

for dirpath, dirnames, filenames in os.walk(project_name):
    # Ignore dirnames that start with '.'
    for i, dirname in enumerate(dirnames):
        if dirname.startswith('.'):
            del dirnames[i]
    if '__init__.py' in filenames:
        pkg = dirpath.replace(os.path.sep, '.')
        if os.path.altsep:
            pkg = pkg.replace(os.path.altsep, '.')
        packages.append(pkg)
    elif filenames:
        prefix = dirpath[(len(project_name) + 1):]
        for f in filenames:
            data_files.append(os.path.join(prefix, f))

setup(
    name='django-easyconfig',
    version=version,
    package_dir={project_name: project_name},
    packages=packages,
    package_data={project_name: data_files},
    description='Module to make it easy to configure external Django apps.',
    author='Peter Sanchez',
    author_email='petersanchez@gmail.com',
    license='BSD License',
    url='http://bitbucket.org/petersanchez/django-easyconfig/',
    long_description=long_description,
    platforms=['any'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Environment :: Web Environment',
    ],
)
